@@ -726,7 +726,7 @@ void PrintOptions_h4toh5(void)
 {
   fprintf(stderr,"\nUsage: ");
   fprintf(stderr,"\n  h4toh5 -h (gives this print-out)\n");
-  fprintf(stderr,"  h4toh5 -na(can convert without HDF4 specified attributes)\n");
+  fprintf(stderr,"  h4toh5 -na(will not add the predefined attributes that specify the HDF4 object information)\n");
   fprintf(stderr,"  h4toh5 input.hdf output.h5\n");
   fprintf(stderr,"  h4toh5 input.hdf\n");
   fprintf(stderr,"  h4toh5 -na input.hdf output.h5\n");
